pub enum ItsMessage<'a> {
DenmV1 {
geonetworking: Option<Packet<'a>>,
transport: Option<Box<TransportHeader>>,
etsi: Box<DENM>,
},
DenmV2 {
geonetworking: Option<Packet<'a>>,
transport: Option<Box<TransportHeader>>,
etsi: Box<DENM>,
},
Cam {
geonetworking: Option<Packet<'a>>,
transport: Option<Box<TransportHeader>>,
etsi: Box<CAM>,
},
Spatem {
geonetworking: Option<Packet<'a>>,
transport: Option<Box<TransportHeader>>,
etsi: Box<SPATEM>,
},
Mapem {
geonetworking: Option<Packet<'a>>,
transport: Option<Box<TransportHeader>>,
etsi: Box<MAPEM>,
},
IvimV1 {
geonetworking: Option<Packet<'a>>,
transport: Option<Box<TransportHeader>>,
etsi: Box<IVIM>,
},
IvimV2 {
geonetworking: Option<Packet<'a>>,
transport: Option<Box<TransportHeader>>,
etsi: Box<IVIM>,
},
Srem {
geonetworking: Option<Packet<'a>>,
transport: Option<Box<TransportHeader>>,
etsi: Box<SREM>,
},
Ssem {
geonetworking: Option<Packet<'a>>,
transport: Option<Box<TransportHeader>>,
etsi: Box<SSEM>,
},
CpmV1 {
geonetworking: Option<Packet<'a>>,
transport: Option<Box<TransportHeader>>,
etsi: Box<CPM>,
},
CpmV2 {
geonetworking: Option<Packet<'a>>,
transport: Option<Box<TransportHeader>>,
etsi: Box<CollectivePerceptionMessage>,
},
}Expand description
Wrapper for C-ITS messages
Each message consists of the etsi data and can optionally contain a transport (BTP) and a geonetworking header.
Variants
DenmV1
ETSI EN 302 637-3 v1.3.1 DENM
DenmV2
ETSI TS 103 831 v2.2.1 (or v2.1.1) DENM
Cam
ETSI TS 103 301 v2.2.1 (or v2.1.1 or v1.3.1) CAM
Spatem
ETSI TS 103 301 v2.2.1 (or v2.1.1 or v1.3.1) SPATEM
Mapem
ETSI TS 103 301 v2.2.1 (or v2.1.1 or v1.3.1) MAPEM
IvimV1
ETSI TS 103 301 v2.1.1 (or v1.3.1) IVIM
IvimV2
ETSI TS 103 301 v2.2.1 IVIM
Srem
ETSI TS 103 301 v2.2.1 (or v2.1.1 or v1.3.1) SREM
Ssem
ETSI TS 103 301 v2.2.1 (or v2.1.1 or v1.3.1) SSEM
CpmV1
ETSI TR 103 562 v2.1.1 CPM
CpmV2
ETSI TS 103 324 v2.1.1 CPM
Implementations
Sourceimpl ItsMessage<'_>
impl ItsMessage<'_>
Sourcepub fn encode(self, encoding_rules: EncodingRules) -> Result<Encoded, String>
pub fn encode(self, encoding_rules: EncodingRules) -> Result<Encoded, String>
Encodes an ITS message with optional headers.
Supports XER, JER, and UPER encoding rules. XER and JER values are returned as UTF-8 buffers.
Errors
Gives a human-readable error description when ASN.1 parsing failed or an unexpected set of headers was found.