Module geo_utils

Module geo_utils 

Available on crate feature geo only.
Conversions from ETSI to geo-types

Take a look at the individual data types in crate::standards to discover available conversion methods and initialization functions.

Note: These conversions are only available with the optional geo feature flag. And when used in a no_std environment, the libm flags is required for conversions from X/Y delta positions.

Functions

point_from_dxy
Convert ETSI XY deltas to absolute lon/lat position (in degrees)