Module pcap

Module pcap 

Available on crate feature transport only.

Functions

extract_80211_hdr
Extracts IEEE 802.11p header from a binary message buffer and returns the header and remaining buffer
extract_llc_hdr
Extracts LLC header from a binary message buffer and returns the header and remaining buffer
extract_radiotap_hdr
Extracts Radiotap header from a binary message buffer and returns the header and remaining buffer
remove_80211_hdr
Strips IEEE 802.11p header from a binary message buffer
remove_llc_hdr
Strips LLC header from a binary message buffer
remove_pcap_headers
Strips Radiotap, IEEE 802.11p and LLC headers from a binary message buffer
remove_radiotap_hdr
Strips Radiotap header from a binary message buffer
remove_wlan_headers
Strips IEEE 802.11p and LLC headers from a binary message buffer