CauseCodeChoice

Enum CauseCodeChoice 

pub enum CauseCodeChoice {
Show 129 variants reserved0(SubCauseCodeType), trafficCondition1(TrafficConditionSubCauseCode), accident2(AccidentSubCauseCode), roadworks3(RoadworksSubCauseCode), reserved4(SubCauseCodeType), impassability5(ImpassabilitySubCauseCode), adverseWeatherCondition_Adhesion6(AdverseWeatherConditionAdhesionSubCauseCode), aquaplaning7(SubCauseCodeType), reserved8(SubCauseCodeType), hazardousLocation_SurfaceCondition9(HazardousLocationSurfaceConditionSubCauseCode), hazardousLocation_ObstacleOnTheRoad10(HazardousLocationObstacleOnTheRoadSubCauseCode), hazardousLocation_AnimalOnTheRoad11(HazardousLocationAnimalOnTheRoadSubCauseCode), humanPresenceOnTheRoad12(HumanPresenceOnTheRoadSubCauseCode), reserved13(SubCauseCodeType), wrongWayDriving14(WrongWayDrivingSubCauseCode), rescueAndRecoveryWorkInProgress15(RescueAndRecoveryWorkInProgressSubCauseCode), reserved16(SubCauseCodeType), adverseWeatherCondition_ExtremeWeatherCondition17(AdverseWeatherConditionExtremeWeatherConditionSubCauseCode), adverseWeatherCondition_Visibility18(AdverseWeatherConditionVisibilitySubCauseCode), adverseWeatherCondition_Precipitation19(AdverseWeatherConditionPrecipitationSubCauseCode), violence20(SubCauseCodeType), reserved21(SubCauseCodeType), reserved22(SubCauseCodeType), reserved23(SubCauseCodeType), reserved24(SubCauseCodeType), reserved25(SubCauseCodeType), slowVehicle26(SlowVehicleSubCauseCode), dangerousEndOfQueue27(DangerousEndOfQueueSubCauseCode), publicTransportVehicleApproaching28(SubCauseCodeType), reserved29(SubCauseCodeType), reserved30(SubCauseCodeType), reserved31(SubCauseCodeType), reserved32(SubCauseCodeType), reserved33(SubCauseCodeType), reserved34(SubCauseCodeType), reserved35(SubCauseCodeType), reserved36(SubCauseCodeType), reserved37(SubCauseCodeType), reserved38(SubCauseCodeType), reserved39(SubCauseCodeType), reserved40(SubCauseCodeType), reserved41(SubCauseCodeType), reserved42(SubCauseCodeType), reserved43(SubCauseCodeType), reserved44(SubCauseCodeType), reserved45(SubCauseCodeType), reserved46(SubCauseCodeType), reserved47(SubCauseCodeType), reserved48(SubCauseCodeType), reserved49(SubCauseCodeType), reserved50(SubCauseCodeType), reserved51(SubCauseCodeType), reserved52(SubCauseCodeType), reserved53(SubCauseCodeType), reserved54(SubCauseCodeType), reserved55(SubCauseCodeType), reserved56(SubCauseCodeType), reserved57(SubCauseCodeType), reserved58(SubCauseCodeType), reserved59(SubCauseCodeType), reserved60(SubCauseCodeType), reserved61(SubCauseCodeType), reserved62(SubCauseCodeType), reserved63(SubCauseCodeType), reserved64(SubCauseCodeType), reserved65(SubCauseCodeType), reserved66(SubCauseCodeType), reserved67(SubCauseCodeType), reserved68(SubCauseCodeType), reserved69(SubCauseCodeType), reserved70(SubCauseCodeType), reserved71(SubCauseCodeType), reserved72(SubCauseCodeType), reserved73(SubCauseCodeType), reserved74(SubCauseCodeType), reserved75(SubCauseCodeType), reserved76(SubCauseCodeType), reserved77(SubCauseCodeType), reserved78(SubCauseCodeType), reserved79(SubCauseCodeType), reserved80(SubCauseCodeType), reserved81(SubCauseCodeType), reserved82(SubCauseCodeType), reserved83(SubCauseCodeType), reserved84(SubCauseCodeType), reserved85(SubCauseCodeType), reserved86(SubCauseCodeType), reserved87(SubCauseCodeType), reserved88(SubCauseCodeType), reserved89(SubCauseCodeType), reserved90(SubCauseCodeType), vehicleBreakdown91(VehicleBreakdownSubCauseCode), postCrash92(PostCrashSubCauseCode), humanProblem93(HumanProblemSubCauseCode), stationaryVehicle94(StationaryVehicleSubCauseCode), emergencyVehicleApproaching95(EmergencyVehicleApproachingSubCauseCode), hazardousLocation_DangerousCurve96(HazardousLocationDangerousCurveSubCauseCode), collisionRisk97(CollisionRiskSubCauseCode), signalViolation98(SignalViolationSubCauseCode), dangerousSituation99(DangerousSituationSubCauseCode), railwayLevelCrossing100(RailwayLevelCrossingSubCauseCode), reserved101(SubCauseCodeType), reserved102(SubCauseCodeType), reserved103(SubCauseCodeType), reserved104(SubCauseCodeType), reserved105(SubCauseCodeType), reserved106(SubCauseCodeType), reserved107(SubCauseCodeType), reserved108(SubCauseCodeType), reserved109(SubCauseCodeType), reserved110(SubCauseCodeType), reserved111(SubCauseCodeType), reserved112(SubCauseCodeType), reserved113(SubCauseCodeType), reserved114(SubCauseCodeType), reserved115(SubCauseCodeType), reserved116(SubCauseCodeType), reserved117(SubCauseCodeType), reserved118(SubCauseCodeType), reserved119(SubCauseCodeType), reserved120(SubCauseCodeType), reserved121(SubCauseCodeType), reserved122(SubCauseCodeType), reserved123(SubCauseCodeType), reserved124(SubCauseCodeType), reserved125(SubCauseCodeType), reserved126(SubCauseCodeType), reserved127(SubCauseCodeType), reserved128(SubCauseCodeType),
}
Available on crate feature _etsi and (crate features _cdd_2_2_1 or _etsi) only.
This DF is a representation of the cause code value and associated sub cause code value of a traffic event.

The following options are available:

  • 0 - reserved for future use,
  • 1 - trafficCondition1 - in case the type of event is an abnormal traffic condition,
  • 2 - accident2 - in case the type of event is a road accident,
  • 3 - roadworks3 - in case the type of event is roadwork,
  • 4 - reserved for future usage,
  • 5 - impassability5 - in case the type of event is unmanaged road blocking, referring to any blocking of a road, partial or total, which has not been adequately secured and signposted,
  • 6 - adverseWeatherCondition-Adhesion6 - in case the type of event is low adhesion,
  • 7 - aquaplaning7 - danger of aquaplaning on the road,
  • 8 - reserved for future usage,
  • 9 - hazardousLocation-SurfaceCondition9 - in case the type of event is abnormal road surface condition,
  • 10 - hazardousLocation-ObstacleOnTheRoad10 - in case the type of event is obstacle on the road,
  • 11 - hazardousLocation-AnimalOnTheRoad11 - in case the type of event is animal on the road,
  • 12 - humanPresenceOnTheRoad - in case the type of event is presence of human vulnerable road user on the road,
  • 13 - reserved for future usage,
  • 14 - wrongWayDriving14 - in case the type of the event is vehicle driving in wrong way,
  • 15 - rescueAndRecoveryWorkInProgress15 - in case the type of event is rescue and recovery work for accident or for a road hazard in progress,
  • 16 - reserved for future usage,
  • 17 - adverseWeatherCondition-ExtremeWeatherCondition17 - in case the type of event is extreme weather condition,
  • 18 - adverseWeatherCondition-Visibility18 - in case the type of event is low visibility,
  • 19 - adverseWeatherCondition-Precipitation19 - in case the type of event is precipitation,
  • 20 - violence20 - in case the the type of event is human violence on or near the road,
  • 21-25 - reserved for future usage,
  • 26 - slowVehicle26 - in case the type of event is slow vehicle driving on the road,
  • 27 - dangerousEndOfQueue27 - in case the type of event is dangerous end of vehicle queue,
  • 28 - `publicTransportVehicleApproaching - in case the type of event is a public transport vehicle approaching, with a priority defined by applicable traffic regulations,
  • 29-90 - are reserved for future usage,
  • 91 - vehicleBreakdown91 - in case the type of event is break down vehicle on the road,
  • 92 - postCrash92 - in case the type of event is a detected crash,
  • 93 - humanProblem93 - in case the type of event is human health problem in vehicles involved in traffic,
  • 94 - stationaryVehicle94 - in case the type of event is stationary vehicle,
  • 95 - emergencyVehicleApproaching95 - in case the type of event is an approaching vehicle operating on a mission for which the applicable traffic regulations provide it with defined priority rights in traffic.
  • 96 - hazardousLocation-DangerousCurve96 - in case the type of event is dangerous curve,
  • 97 - collisionRisk97 - in case the type of event is a collision risk,
  • 98 - signalViolation98 - in case the type of event is signal violation,
  • 99 - dangerousSituation99 - in case the type of event is dangerous situation in which autonomous safety system in vehicle is activated,
  • 100 - railwayLevelCrossing100 - in case the type of event is a railway level crossing.
  • 101-255 - are reserved for future usage.

@note: this DF is defined for use as part of CauseCodeV2. It is recommended to use CauseCodeV2.

@category: Traffic information

@revision: Created in V2.1.1, the type of impassability5 changed to ImpassabilitySubCauseCode in V2.2.1, value 28 added in V2.2.1, definition of value 12 and 95 changed in V2.2.1

Variants



reserved0(SubCauseCodeType)



trafficCondition1(TrafficConditionSubCauseCode)



accident2(AccidentSubCauseCode)



roadworks3(RoadworksSubCauseCode)



reserved4(SubCauseCodeType)



impassability5(ImpassabilitySubCauseCode)



adverseWeatherCondition_Adhesion6(AdverseWeatherConditionAdhesionSubCauseCode)



aquaplaning7(SubCauseCodeType)



reserved8(SubCauseCodeType)



hazardousLocation_SurfaceCondition9(HazardousLocationSurfaceConditionSubCauseCode)



hazardousLocation_ObstacleOnTheRoad10(HazardousLocationObstacleOnTheRoadSubCauseCode)



hazardousLocation_AnimalOnTheRoad11(HazardousLocationAnimalOnTheRoadSubCauseCode)



humanPresenceOnTheRoad12(HumanPresenceOnTheRoadSubCauseCode)



reserved13(SubCauseCodeType)



wrongWayDriving14(WrongWayDrivingSubCauseCode)



rescueAndRecoveryWorkInProgress15(RescueAndRecoveryWorkInProgressSubCauseCode)



reserved16(SubCauseCodeType)



adverseWeatherCondition_ExtremeWeatherCondition17(AdverseWeatherConditionExtremeWeatherConditionSubCauseCode)



adverseWeatherCondition_Visibility18(AdverseWeatherConditionVisibilitySubCauseCode)



adverseWeatherCondition_Precipitation19(AdverseWeatherConditionPrecipitationSubCauseCode)



violence20(SubCauseCodeType)



reserved21(SubCauseCodeType)



reserved22(SubCauseCodeType)



reserved23(SubCauseCodeType)



reserved24(SubCauseCodeType)



reserved25(SubCauseCodeType)



slowVehicle26(SlowVehicleSubCauseCode)



dangerousEndOfQueue27(DangerousEndOfQueueSubCauseCode)



publicTransportVehicleApproaching28(SubCauseCodeType)



reserved29(SubCauseCodeType)



reserved30(SubCauseCodeType)



reserved31(SubCauseCodeType)



reserved32(SubCauseCodeType)



reserved33(SubCauseCodeType)



reserved34(SubCauseCodeType)



reserved35(SubCauseCodeType)



reserved36(SubCauseCodeType)



reserved37(SubCauseCodeType)



reserved38(SubCauseCodeType)



reserved39(SubCauseCodeType)



reserved40(SubCauseCodeType)



reserved41(SubCauseCodeType)



reserved42(SubCauseCodeType)



reserved43(SubCauseCodeType)



reserved44(SubCauseCodeType)



reserved45(SubCauseCodeType)



reserved46(SubCauseCodeType)



reserved47(SubCauseCodeType)



reserved48(SubCauseCodeType)



reserved49(SubCauseCodeType)



reserved50(SubCauseCodeType)



reserved51(SubCauseCodeType)



reserved52(SubCauseCodeType)



reserved53(SubCauseCodeType)



reserved54(SubCauseCodeType)



reserved55(SubCauseCodeType)



reserved56(SubCauseCodeType)



reserved57(SubCauseCodeType)



reserved58(SubCauseCodeType)



reserved59(SubCauseCodeType)



reserved60(SubCauseCodeType)



reserved61(SubCauseCodeType)



reserved62(SubCauseCodeType)



reserved63(SubCauseCodeType)



reserved64(SubCauseCodeType)



reserved65(SubCauseCodeType)



reserved66(SubCauseCodeType)



reserved67(SubCauseCodeType)



reserved68(SubCauseCodeType)



reserved69(SubCauseCodeType)



reserved70(SubCauseCodeType)



reserved71(SubCauseCodeType)



reserved72(SubCauseCodeType)



reserved73(SubCauseCodeType)



reserved74(SubCauseCodeType)



reserved75(SubCauseCodeType)



reserved76(SubCauseCodeType)



reserved77(SubCauseCodeType)



reserved78(SubCauseCodeType)



reserved79(SubCauseCodeType)



reserved80(SubCauseCodeType)



reserved81(SubCauseCodeType)



reserved82(SubCauseCodeType)



reserved83(SubCauseCodeType)



reserved84(SubCauseCodeType)



reserved85(SubCauseCodeType)



reserved86(SubCauseCodeType)



reserved87(SubCauseCodeType)



reserved88(SubCauseCodeType)



reserved89(SubCauseCodeType)



reserved90(SubCauseCodeType)



vehicleBreakdown91(VehicleBreakdownSubCauseCode)



postCrash92(PostCrashSubCauseCode)



humanProblem93(HumanProblemSubCauseCode)



stationaryVehicle94(StationaryVehicleSubCauseCode)



emergencyVehicleApproaching95(EmergencyVehicleApproachingSubCauseCode)



hazardousLocation_DangerousCurve96(HazardousLocationDangerousCurveSubCauseCode)



collisionRisk97(CollisionRiskSubCauseCode)



signalViolation98(SignalViolationSubCauseCode)



dangerousSituation99(DangerousSituationSubCauseCode)



railwayLevelCrossing100(RailwayLevelCrossingSubCauseCode)



reserved101(SubCauseCodeType)



reserved102(SubCauseCodeType)



reserved103(SubCauseCodeType)



reserved104(SubCauseCodeType)



reserved105(SubCauseCodeType)



reserved106(SubCauseCodeType)



reserved107(SubCauseCodeType)



reserved108(SubCauseCodeType)



reserved109(SubCauseCodeType)



reserved110(SubCauseCodeType)



reserved111(SubCauseCodeType)



reserved112(SubCauseCodeType)



reserved113(SubCauseCodeType)



reserved114(SubCauseCodeType)



reserved115(SubCauseCodeType)



reserved116(SubCauseCodeType)



reserved117(SubCauseCodeType)



reserved118(SubCauseCodeType)



reserved119(SubCauseCodeType)



reserved120(SubCauseCodeType)



reserved121(SubCauseCodeType)



reserved122(SubCauseCodeType)



reserved123(SubCauseCodeType)



reserved124(SubCauseCodeType)



reserved125(SubCauseCodeType)



reserved126(SubCauseCodeType)



reserved127(SubCauseCodeType)



reserved128(SubCauseCodeType)

Implementations

Source

impl CauseCodeChoice

pub fn to_u8_tuple(&self) -> (u8, u8)

Available on crate feature _cdd_2_2_1 only.

Converts a Cause Code to an integer tuple of cause code and sub cause code ID