pub struct AccelerationControl(pub FixedBitString<7usize>);_etsi and (crate features _cdd_2_2_1 or _etsi) only.Expand description
This DE indicates the current controlling mechanism for longitudinal movement of the vehicle. The data may be provided via the in-vehicle network. It indicates whether a specific in-vehicle acceleration control system is engaged or not. Currently, this DE includes the information of the vehicle brake pedal, gas pedal, emergency brake system, collision warning system, adaptive cruise control system, cruise control system and speed limiter system.
The corresponding bit shall be set to 1 under the following conditions:
- 0 -
brakePedalEngaged- Driver is stepping on the brake pedal, - 1 -
gasPedalEngaged- Driver is stepping on the gas pedal, - 2 -
emergencyBrakeEngaged- emergency brake system is engaged, - 3 -
collisionWarningEngaged- collision warning system is engaged, - 4 -
accEngaged- ACC is engaged, - 5 -
cruiseControlEngaged- cruise control is engaged, - 6 -
speedLimiterEngaged- speed limiter is engaged.
Otherwise (for example when the corresponding system is not available due to non equipped system or information is unavailable), the corresponding bit shall be set to 0.
@note: The system engagement condition is OEM specific and therefore out of scope of the present document.
@category: Vehicle information
@revision: V1.3.1
Tuple Fields
0: FixedBitString<7usize>Trait Implementations
Sourceimpl AsnType for AccelerationControl
impl AsnType for AccelerationControl
Sourceconst TAG: Tag = { <FixedBitString<7usize> as rasn::AsnType>::TAG }
const TAG: Tag = { <FixedBitString<7usize> as rasn::AsnType>::TAG }
Sourceconst IDENTIFIER: Identifier
const IDENTIFIER: Identifier
SelfSourceconst CONSTRAINTS: Constraints
const CONSTRAINTS: Constraints
Sourceconst TAG_TREE: TagTree = _
const TAG_TREE: TagTree = _
Leaf that points Self::TAG.Sourceconst IS_CHOICE: bool = false
const IS_CHOICE: bool = false
Sourcefn is_present(&self) -> bool
fn is_present(&self) -> bool
Sourceimpl Clone for AccelerationControl
impl Clone for AccelerationControl
Sourcefn clone(&self) -> AccelerationControl
fn clone(&self) -> AccelerationControl
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Debug for AccelerationControl
impl Debug for AccelerationControl
Sourceimpl Decode for AccelerationControl
impl Decode for AccelerationControl
Sourcefn decode_with_tag_and_constraints<_DECODER: Decoder>(
decoder: &mut _DECODER,
tag: Tag,
constraints: Constraints,
) -> Result<Self, _DECODER::Error>
fn decode_with_tag_and_constraints<_DECODER: Decoder>( decoder: &mut _DECODER, tag: Tag, constraints: Constraints, ) -> Result<Self, _DECODER::Error>
tag from a given ASN.1
decoder with a set of constraints on what values of that type are allowed. Read moreSourcefn decode<D>(decoder: &mut D) -> Result<Self, <D as Decoder>::Error>where
D: Decoder,
fn decode<D>(decoder: &mut D) -> Result<Self, <D as Decoder>::Error>where
D: Decoder,
Sourcefn decode_with_tag<D>(
decoder: &mut D,
tag: Tag,
) -> Result<Self, <D as Decoder>::Error>where
D: Decoder,
fn decode_with_tag<D>(
decoder: &mut D,
tag: Tag,
) -> Result<Self, <D as Decoder>::Error>where
D: Decoder,
tag from a given ASN.1 decoder. Read moreSourcefn decode_with_constraints<D>(
decoder: &mut D,
constraints: Constraints,
) -> Result<Self, <D as Decoder>::Error>where
D: Decoder,
fn decode_with_constraints<D>(
decoder: &mut D,
constraints: Constraints,
) -> Result<Self, <D as Decoder>::Error>where
D: Decoder,
Sourceimpl Encode for AccelerationControl
impl Encode for AccelerationControl
Sourcefn encode_with_tag_and_constraints<'encoder, _ENCODER: Encoder<'encoder>>(
&self,
encoder: &mut _ENCODER,
tag: Tag,
constraints: Constraints,
identifier: Identifier,
) -> Result<(), _ENCODER::Error>
fn encode_with_tag_and_constraints<'encoder, _ENCODER: Encoder<'encoder>>( &self, encoder: &mut _ENCODER, tag: Tag, constraints: Constraints, identifier: Identifier, ) -> Result<(), _ENCODER::Error>
tag into the given crate::Encoder with the
constraints the values this is allowed to encode into. Read moreSourcefn encode<'b, E>(
&self,
encoder: &mut E,
) -> Result<(), <E as Encoder<'b>>::Error>where
E: Encoder<'b>,
fn encode<'b, E>(
&self,
encoder: &mut E,
) -> Result<(), <E as Encoder<'b>>::Error>where
E: Encoder<'b>,
Sourcefn encode_with_tag<'b, E>(
&self,
encoder: &mut E,
tag: Tag,
) -> Result<(), <E as Encoder<'b>>::Error>where
E: Encoder<'b>,
fn encode_with_tag<'b, E>(
&self,
encoder: &mut E,
tag: Tag,
) -> Result<(), <E as Encoder<'b>>::Error>where
E: Encoder<'b>,
Sourcefn encode_with_identifier<'b, E>(
&self,
encoder: &mut E,
identifier: Identifier,
) -> Result<(), <E as Encoder<'b>>::Error>where
E: Encoder<'b>,
fn encode_with_identifier<'b, E>(
&self,
encoder: &mut E,
identifier: Identifier,
) -> Result<(), <E as Encoder<'b>>::Error>where
E: Encoder<'b>,
Sourcefn encode_with_tag_and_identifier<'b, E>(
&self,
encoder: &mut E,
tag: Tag,
identifier: Identifier,
) -> Result<(), <E as Encoder<'b>>::Error>where
E: Encoder<'b>,
fn encode_with_tag_and_identifier<'b, E>(
&self,
encoder: &mut E,
tag: Tag,
identifier: Identifier,
) -> Result<(), <E as Encoder<'b>>::Error>where
E: Encoder<'b>,
Sourcefn encode_with_constraints<'b, E>(
&self,
encoder: &mut E,
constraints: Constraints,
) -> Result<(), <E as Encoder<'b>>::Error>where
E: Encoder<'b>,
fn encode_with_constraints<'b, E>(
&self,
encoder: &mut E,
constraints: Constraints,
) -> Result<(), <E as Encoder<'b>>::Error>where
E: Encoder<'b>,
crate::Encoder with the
constraints the values this is allowed to encode into. Read moreSourcefn encode_with_constraints_and_identifier<'b, E>(
&self,
encoder: &mut E,
constraints: Constraints,
identifier: Identifier,
) -> Result<(), <E as Encoder<'b>>::Error>where
E: Encoder<'b>,
fn encode_with_constraints_and_identifier<'b, E>(
&self,
encoder: &mut E,
constraints: Constraints,
identifier: Identifier,
) -> Result<(), <E as Encoder<'b>>::Error>where
E: Encoder<'b>,
crate::Encoder with identifier and the
constraints the values this is allowed to encode into. Read moreimpl Eq for AccelerationControl
Sourceimpl Hash for AccelerationControl
impl Hash for AccelerationControl
Sourceimpl PartialEq for AccelerationControl
impl PartialEq for AccelerationControl
Sourcefn eq(&self, other: &AccelerationControl) -> bool
fn eq(&self, other: &AccelerationControl) -> bool
self and other values to be equal, and is used by ==.impl StructuralPartialEq for AccelerationControl