pub struct CartesianAngularAccelerationComponentValue(pub i16);Available on crate feature
_etsi and (crate features _cdd_2_2_1 or _etsi) only.Expand description
This DE represents an angular acceleration value described in a local Cartesian coordinate system, per default counted positive in a right-hand local coordinate system from the abscissa.
- The value shall be set to:
-255if the acceleration is equal to or less than -255 degrees/s^2,n(n > -255andn < 255) if the acceleration is equal to or less than n x 1 degree/s^2, and greater than(n-1)x 0,01 degree/s^2,255if the acceleration is greater than 254 degrees/s^2,256if the information is unavailable.
@unit: degree/s^2 (degrees per second squared)
@category: Kinematic information
@revision: Created in V2.1.1
Tuple Fields
0: i16Trait Implementations
Sourceimpl AsnType for CartesianAngularAccelerationComponentValue
impl AsnType for CartesianAngularAccelerationComponentValue
Sourceconst IDENTIFIER: Identifier
const IDENTIFIER: Identifier
Identifier of an ASN.1 type as specified in the original specification
if not identical with the identifier of
SelfSourceconst CONSTRAINTS: Constraints
const CONSTRAINTS: Constraints
The set of constraints for values of the given type.
Sourceconst TAG_TREE: TagTree = _
const TAG_TREE: TagTree = _
The root of this type’s tree of tag’s if it a CHOICE type, otherwise its
Leaf that points Self::TAG.Sourceconst IS_CHOICE: bool = false
const IS_CHOICE: bool = false
Whether the type is choice type. PER/OER encoding rules require this knowledge.
Sourcefn is_present(&self) -> bool
fn is_present(&self) -> bool
Sourceimpl Clone for CartesianAngularAccelerationComponentValue
impl Clone for CartesianAngularAccelerationComponentValue
Sourcefn clone(&self) -> CartesianAngularAccelerationComponentValue
fn clone(&self) -> CartesianAngularAccelerationComponentValue
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Decode for CartesianAngularAccelerationComponentValue
impl Decode for CartesianAngularAccelerationComponentValue
Sourcefn decode_with_tag_and_constraints<_DECODER: Decoder>(
decoder: &mut _DECODER,
tag: Tag,
constraints: Constraints,
) -> Result<Self, _DECODER::Error>
fn decode_with_tag_and_constraints<_DECODER: Decoder>( decoder: &mut _DECODER, tag: Tag, constraints: Constraints, ) -> Result<Self, _DECODER::Error>
Decode this value implicitly tagged with
tag from a given ASN.1
decoder with a set of constraints on what values of that type are allowed. Read moreSourcefn decode<D>(decoder: &mut D) -> Result<Self, <D as Decoder>::Error>where
D: Decoder,
fn decode<D>(decoder: &mut D) -> Result<Self, <D as Decoder>::Error>where
D: Decoder,
Decode this value from a given ASN.1 decoder. Read more
Sourcefn decode_with_tag<D>(
decoder: &mut D,
tag: Tag,
) -> Result<Self, <D as Decoder>::Error>where
D: Decoder,
fn decode_with_tag<D>(
decoder: &mut D,
tag: Tag,
) -> Result<Self, <D as Decoder>::Error>where
D: Decoder,
Decode this value implicitly tagged with
tag from a given ASN.1 decoder. Read moreSourcefn decode_with_constraints<D>(
decoder: &mut D,
constraints: Constraints,
) -> Result<Self, <D as Decoder>::Error>where
D: Decoder,
fn decode_with_constraints<D>(
decoder: &mut D,
constraints: Constraints,
) -> Result<Self, <D as Decoder>::Error>where
D: Decoder,
Decode this value from a given ASN.1 decoder with a set of constraints
on what values of that type are allowed. Read more
Sourceimpl Encode for CartesianAngularAccelerationComponentValue
impl Encode for CartesianAngularAccelerationComponentValue
Sourcefn encode_with_tag_and_constraints<'encoder, _ENCODER: Encoder<'encoder>>(
&self,
encoder: &mut _ENCODER,
tag: Tag,
constraints: Constraints,
identifier: Identifier,
) -> Result<(), _ENCODER::Error>
fn encode_with_tag_and_constraints<'encoder, _ENCODER: Encoder<'encoder>>( &self, encoder: &mut _ENCODER, tag: Tag, constraints: Constraints, identifier: Identifier, ) -> Result<(), _ENCODER::Error>
Encode this value with
tag into the given crate::Encoder with the
constraints the values this is allowed to encode into. Read moreSourcefn encode<'b, E>(
&self,
encoder: &mut E,
) -> Result<(), <E as Encoder<'b>>::Error>where
E: Encoder<'b>,
fn encode<'b, E>(
&self,
encoder: &mut E,
) -> Result<(), <E as Encoder<'b>>::Error>where
E: Encoder<'b>,
Sourcefn encode_with_tag<'b, E>(
&self,
encoder: &mut E,
tag: Tag,
) -> Result<(), <E as Encoder<'b>>::Error>where
E: Encoder<'b>,
fn encode_with_tag<'b, E>(
&self,
encoder: &mut E,
tag: Tag,
) -> Result<(), <E as Encoder<'b>>::Error>where
E: Encoder<'b>,
Sourcefn encode_with_identifier<'b, E>(
&self,
encoder: &mut E,
identifier: Identifier,
) -> Result<(), <E as Encoder<'b>>::Error>where
E: Encoder<'b>,
fn encode_with_identifier<'b, E>(
&self,
encoder: &mut E,
identifier: Identifier,
) -> Result<(), <E as Encoder<'b>>::Error>where
E: Encoder<'b>,
Sourcefn encode_with_tag_and_identifier<'b, E>(
&self,
encoder: &mut E,
tag: Tag,
identifier: Identifier,
) -> Result<(), <E as Encoder<'b>>::Error>where
E: Encoder<'b>,
fn encode_with_tag_and_identifier<'b, E>(
&self,
encoder: &mut E,
tag: Tag,
identifier: Identifier,
) -> Result<(), <E as Encoder<'b>>::Error>where
E: Encoder<'b>,
Sourcefn encode_with_constraints<'b, E>(
&self,
encoder: &mut E,
constraints: Constraints,
) -> Result<(), <E as Encoder<'b>>::Error>where
E: Encoder<'b>,
fn encode_with_constraints<'b, E>(
&self,
encoder: &mut E,
constraints: Constraints,
) -> Result<(), <E as Encoder<'b>>::Error>where
E: Encoder<'b>,
Encode this value into the given
crate::Encoder with the
constraints the values this is allowed to encode into. Read moreSourcefn encode_with_constraints_and_identifier<'b, E>(
&self,
encoder: &mut E,
constraints: Constraints,
identifier: Identifier,
) -> Result<(), <E as Encoder<'b>>::Error>where
E: Encoder<'b>,
fn encode_with_constraints_and_identifier<'b, E>(
&self,
encoder: &mut E,
constraints: Constraints,
identifier: Identifier,
) -> Result<(), <E as Encoder<'b>>::Error>where
E: Encoder<'b>,
Encode this value into the given
crate::Encoder with identifier and the
constraints the values this is allowed to encode into. Read moreimpl Eq for CartesianAngularAccelerationComponentValue
Sourceimpl PartialEq for CartesianAngularAccelerationComponentValue
impl PartialEq for CartesianAngularAccelerationComponentValue
Sourcefn eq(&self, other: &CartesianAngularAccelerationComponentValue) -> bool
fn eq(&self, other: &CartesianAngularAccelerationComponentValue) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for CartesianAngularAccelerationComponentValue