pub struct LowerTriangularPositiveSemidefiniteMatrix {
pub components_included_inthe_matrix: MatrixIncludedComponents,
pub matrix: LowerTriangularPositiveSemidefiniteMatrixColumns,
}_etsi and (crate features _cdd_2_2_1 or _etsi) only.Expand description
This DF represents a lower triangular positive semi-definite matrix.
It shall include the following components:
-
@field componentsIncludedIntheMatrix: the indication of which components of a @ref PerceivedObject are included in the matrix. This component also implicitly indicates the number n of included components which defines the size (n x n) of the full correlation matrix “A”.
-
@field matrix: the list of cells of the lower triangular positive semi-definite matrix ordered by columns and by rows.
The number of columns to be included “k” is equal to the number of included components “n” indicated by componentsIncludedIntheMatrix minus 1: k = n-1. These components shall be included in the order or their appearance in componentsIncludedIntheMatrix. Each column “i” of the lowerTriangularCorrelationMatrixColumns contains k-(i-1) values.
@category: Sensing information
@revision: Created in V2.1.1
Fields
components_included_inthe_matrix: MatrixIncludedComponentsmatrix: LowerTriangularPositiveSemidefiniteMatrixColumnsImplementations
Sourceimpl LowerTriangularPositiveSemidefiniteMatrix
impl LowerTriangularPositiveSemidefiniteMatrix
pub fn new( components_included_inthe_matrix: MatrixIncludedComponents, matrix: LowerTriangularPositiveSemidefiniteMatrixColumns, ) -> Self