#[non_exhaustive]pub struct MapemElementReference {
pub map_reference: Option<MapReference>,
pub lane_ids: Option<MapemLaneList>,
pub connection_ids: Option<MapemConnectionList>,
}Available on crate feature
_etsi and (crate features _cdd_2_2_1 or _etsi) only.Expand description
This DF provides references to an element described in a MAPEM according to ETSI TS 103 301 [i.15], such as a lane or connection at a specific intersection or road segment.
It shall include the following components:
-
@field mapReference: the optional reference to a MAPEM that describes the intersection or road segment. It is absent if the MAPEM topology is known from the context.
-
@field laneIds: the optional list of the identifiers of the lanes to be referenced.
-
@field connectionIds: the optional list of the identifiers of the connections to be referenced.
@category: Road topology information
@revision: Created in V2.2.1
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.map_reference: Option<MapReference>lane_ids: Option<MapemLaneList>connection_ids: Option<MapemConnectionList>Implementations
Sourceimpl MapemElementReference
impl MapemElementReference
pub fn new( map_reference: Option<MapReference>, lane_ids: Option<MapemLaneList>, connection_ids: Option<MapemConnectionList>, ) -> Self