#[non_exhaustive]pub struct PathPointPredicted {
pub delta_latitude: DeltaLatitude,
pub delta_longitude: DeltaLongitude,
pub horizontal_position_confidence: Option<PosConfidenceEllipse>,
pub delta_altitude: DeltaAltitude,
pub altitude_confidence: AltitudeConfidence,
pub path_delta_time: Option<PathDeltaTimeChoice>,
pub symmetric_area_offset: Option<StandardLength9b>,
pub asymmetric_area_offset: Option<StandardLength9b>,
}_etsi and (crate features _cdd_2_2_1 or _etsi) only.Expand description
This DF defines a predicted offset position that can be used within a predicted path or trajectory, together with optional data to describe a path zone shape.
It shall include the following components:
-
@field deltaLatitude: the offset latitude with regards to a pre-defined reference position.
-
@field deltaLongitude: the offset longitude with regards to a pre-defined reference position.
-
@field horizontalPositionConfidence: the optional confidence value associated to the horizontal geographical position.
-
@field deltaAltitude: the optional offset altitude with regards to a pre-defined reference position, with default value unavailable.
-
@field altitudeConfidence: the optional confidence value associated to the altitude value of the geographical position, with default value unavailable.
-
@field pathDeltaTime: the optional travel time to the waypoint from the predefined reference position.
-
@field symmetricAreaOffset: the optional symmetric offset to generate a shape, see Annex D for details.
-
@field asymmetricAreaOffset: the optional asymmetric offset to generate a shape, see Annex D for details.
@category GeoReference information
@revision: Created in V2.1.1, type of pathDeltaTime changed and optionality added, fields symmetricAreaOffset and asymmetricAreaOffset added in V2.2.1
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.delta_latitude: DeltaLatitudedelta_longitude: DeltaLongitudehorizontal_position_confidence: Option<PosConfidenceEllipse>delta_altitude: DeltaAltitudealtitude_confidence: AltitudeConfidencepath_delta_time: Option<PathDeltaTimeChoice>symmetric_area_offset: Option<StandardLength9b>asymmetric_area_offset: Option<StandardLength9b>Implementations
Sourceimpl PathPointPredicted
impl PathPointPredicted
pub fn new( delta_latitude: DeltaLatitude, delta_longitude: DeltaLongitude, horizontal_position_confidence: Option<PosConfidenceEllipse>, delta_altitude: DeltaAltitude, altitude_confidence: AltitudeConfidence, path_delta_time: Option<PathDeltaTimeChoice>, symmetric_area_offset: Option<StandardLength9b>, asymmetric_area_offset: Option<StandardLength9b>, ) -> Self