pub struct RectangularShape {
pub shape_reference_point: Option<CartesianPosition3d>,
pub semi_length: StandardLength12b,
pub semi_breadth: StandardLength12b,
pub orientation: Option<CartesianAngleValue>,
pub height: Option<StandardLength12b>,
}Expand description
This DF represents the shape of a rectangular area or a right rectangular prism that is centred
on a reference position defined outside of the context of this DF and oriented w.r.t. a cartesian
coordinate system defined outside of the context of this DF.
It shall include the following components:
@field shapeReferencePoint: represents an optional offset point which the rectangle is centred on with
respect to the reference position. If this component is absent, the externally specified
reference position represents the shape’s reference point.
@field semiLength: represents half the length of the rectangle located in the X-Y Plane.
@field semiBreadth: represents half the breadth of the rectangle located in the X-Y Plane.
@field orientation: represents the optional orientation of the length of the rectangle, measured with positive values turning around the Z-axis using the right-hand rule, starting from the X-axis.
@field height: represents the optional height, present if the shape is a right rectangular prism with height extending in the positive Z-axis.
@category GeoReference information @revision: created in V2.1.1, centerPoint renamed to shapeReferencePoint, the type of the field orientation changed and description revised in V2.2.1
Fields
shape_reference_point: Option<CartesianPosition3d>semi_length: StandardLength12bsemi_breadth: StandardLength12borientation: Option<CartesianAngleValue>height: Option<StandardLength12b>Implementations
Sourceimpl RectangularShape
impl RectangularShape
pub fn new( shape_reference_point: Option<CartesianPosition3d>, semi_length: StandardLength12b, semi_breadth: StandardLength12b, orientation: Option<CartesianAngleValue>, height: Option<StandardLength12b>, ) -> Self