IntersectionStatusObject

Struct IntersectionStatusObject 

pub struct IntersectionStatusObject(pub FixedBitString<16usize>);
Available on crate features _dsrc_2_2_1 and _etsi only.
The Intersection Status Object contains Advanced Traffic Controller (ATC) status information that may be sent to local OBUs as part of the SPAT process. With bits as defined:

  • manualControlIsEnabled - 0: Timing reported is per programmed values, etc. but person at cabinet can manually request that certain intervals are terminated early (e.g. green).
  • stopTimeIsActivated - 1: And all counting/timing has stopped.
  • failureFlash - 2: Above to be used for any detected hardware failures, e.g. conflict monitor as well as for police flash
  • fixedTimeOperation - 5: Schedule of signals is based on time only (i.e. the state can be calculated)
  • trafficDependentOperation - 6: Operation is based on different levels of traffic parameters (requests, duration of gaps or more complex parameters)
  • standbyOperation - 7: Controller: partially switched off or partially amber flashing
  • failureMode - 8: Controller has a problem or failure in operation
  • off - 9: Controller is switched off
  • recentMAPmessageUpdate - 10: Map revision with content changes
  • recentChangeInMAPassignedLanesIDsUsed - 11: Change in MAP’s assigned lanes used (lane changes) Changes in the active lane list description
  • noValidMAPisAvailableAtThisTime - 12: MAP (and various lanes indexes) not available
  • noValidSPATisAvailableAtThisTime - 13: SPAT system is not working at this time
  • Bits 14,15 reserved at this time and shall be zero

@note: All zeros indicate normal operating mode with no recent changes. The duration of the term ‘recent’ is defined by the system performance requirement in use.

@category: Infrastructure information

@revision: V1.3.1

Tuple Fields

0: FixedBitString<16usize>

Implementations

Source

impl IntersectionStatusObject

pub fn get_manual_control_is_enabled(&self) -> bool

pub fn get_stop_time_is_activated(&self) -> bool

pub fn get_failure_flash(&self) -> bool

pub fn get_preempt_is_active(&self) -> bool

pub fn get_signal_priority_is_active(&self) -> bool

pub fn get_fixed_time_operation(&self) -> bool

pub fn get_traffic_dependent_operation(&self) -> bool

pub fn get_standby_operation(&self) -> bool

pub fn get_failure_mode(&self) -> bool

pub fn get_off(&self) -> bool

pub fn get_recent_map_message_update(&self) -> bool

pub fn get_recent_change_in_map_assigned_lanes_ids_used(&self) -> bool

pub fn get_no_valid_map_is_available_at_this_time(&self) -> bool

pub fn get_no_valid_spat_is_available_at_this_time(&self) -> bool

pub fn set_manual_control_is_enabled(&mut self, value: bool)

pub fn set_stop_time_is_activated(&mut self, value: bool)

pub fn set_failure_flash(&mut self, value: bool)

pub fn set_preempt_is_active(&mut self, value: bool)

pub fn set_signal_priority_is_active(&mut self, value: bool)

pub fn set_fixed_time_operation(&mut self, value: bool)

pub fn set_traffic_dependent_operation(&mut self, value: bool)

pub fn set_standby_operation(&mut self, value: bool)

pub fn set_failure_mode(&mut self, value: bool)

pub fn set_off(&mut self, value: bool)

pub fn set_recent_map_message_update(&mut self, value: bool)

pub fn set_recent_change_in_map_assigned_lanes_ids_used(&mut self, value: bool)

pub fn set_no_valid_map_is_available_at_this_time(&mut self, value: bool)

pub fn set_no_valid_spat_is_available_at_this_time(&mut self, value: bool)