Available on crate feature
_etsi only.Expand description
Manual implementation of things missing from code generated from ASN.1
- rasn-compiler v0.14.3 does not generate a way to access named BIT STRING bits
Modules
- cdd_
1_ 3_ 1_ 1 _cdd_1_3_1_1 - Implementation of additional getters and setters for BITSTRING types with named bits
- cdd_
2_ 2_ 1 _cdd_2_2_1 - Implementation of additional getters and setters for BITSTRING types with named bits
- dsrc_
2_ 2_ 1 _dsrc_2_2_1 - Implementation of additional getters and setters for BITSTRING types with named bits
- its_scc
- DENM Sub Cause Codes
- ivim_
2_ 2_ 1 ivim_2_2_1 - Implementation of additional getters and setters for BITSTRING types with named bits
Enums
- ItsMessage
Id - Enum values for
MessageId - ItsStation
Type - Enum values for
CDD 2.2.1 StationType/CDD 1.3.1 StationType