Module time_utils

Module time_utils 

Available on crate feature time only.
Conversions between ETSI and chrono values

Take a look at the individual data types in crate::standards to discover available conversion methods and initialization functions.

Note: These conversions are only available with the optional time feature flag.

Functions

moy_and_dsecondmapem_2_2_1 or spatem_2_2_1 or srem_2_2_1 or ssem_2_2_1
Converts a UTC time point to ETSI ASN.1 MinuteOfTheYear and DSecond (milliseconds) values.
time_from_moy_and_dsecondmapem_2_2_1 or spatem_2_2_1 or srem_2_2_1 or ssem_2_2_1
Converts ETSI ASN.1 MinuteOfTheYear and DSecond (milliseconds) data to a UTC time point.