Module extensions

Module extensions 

Manual implementation of things missing from code generated from ASN.1

  • rasn-compiler v0.14.3 does not generate a way to access named BIT STRING bits

Modules

cdd_1_3_1_1
Implementation of additional getters and setters for BITSTRING types with named bits
cdd_2_2_1
Implementation of additional getters and setters for BITSTRING types with named bits
dsrc_2_2_1
Implementation of additional getters and setters for BITSTRING types with named bits
its_scc
DENM Sub Cause Codes
ivim_2_2_1
Implementation of additional getters and setters for BITSTRING types with named bits

Enums

ItsMessageId
Enum values for MessageId
ItsStationType
Enum values for CDD 2.2.1 StationType/ CDD 1.3.1 StationType