Available on crate feature
time only.Expand description
Conversions between ETSI and chrono values
Take a look at the individual data types in crate::standards to discover available conversion methods and initialization functions.
Note: These conversions are only available with the optional time feature flag.
Functions
- moy_
and_ dsecond mapem_2_2_1orspatem_2_2_1orsrem_2_2_1orssem_2_2_1 - Converts a UTC time point to ETSI ASN.1
MinuteOfTheYearandDSecond(milliseconds) values. - time_
from_ moy_ and_ dsecond mapem_2_2_1orspatem_2_2_1orsrem_2_2_1orssem_2_2_1 - Converts ETSI ASN.1
MinuteOfTheYearandDSecond(milliseconds) data to a UTC time point.